==> kymang-0.0.6-py3-none-any.whl: kymang/raw/base/messages/translated_text.py <==
#  kymang - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-present Dan <https://github.com/delivrance>
#
#  This file is part of kymang.
#
#  kymang is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  kymang is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with kymang.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from typing import Union
from kymang import raw
from kymang.raw.core import TLObject

TranslatedText = Union[raw.types.messages.TranslateResult]


# noinspection PyRedeclaration
class TranslatedText:  # type: ignore
    """Telegram API base type.

    Constructors:
        This base type has 1 constructor available.

        .. currentmodule:: kymang.raw.types

        .. autosummary::
            :nosignatures:

            messages.TranslateResult

    Functions:
        This object can be returned by 1 function.

        .. currentmodule:: kymang.raw.functions

        .. autosummary::
            :nosignatures:

            messages.TranslateText
    """

    QUALNAME = "kymang.raw.base.messages.TranslatedText"

    def __init__(self):
        raise TypeError("Base types can only be used for type checking purposes: "
                        "you tried to use a base type instance as argument, "
                        "but you need to instantiate one of its constructors instead. "
                        "More info: https://docs.kymang.org/telegram/base/translated-text")

==> kymang-0.1.2-py3-none-any.whl: kymang/raw/base/messages/translated_text.py <==
#  kymang - Telegram MTProto API Client Library for Python.
#  Copyright (C) 2022-2023 Iskandar <https://github.com/darmazi>
#
#  This file is part of kymang.
#
#  kymang is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  kymang is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with kymang.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from typing import Union
from kymang import raw
from kymang.raw.core import TLObject

TranslatedText = Union[raw.types.messages.TranslateNoResult, raw.types.messages.TranslateResultText]


# noinspection PyRedeclaration
class TranslatedText:  # type: ignore
    """Telegram API base type.

    Constructors:
        This base type has 2 constructors available.

        .. currentmodule:: kymang.raw.types

        .. autosummary::
            :nosignatures:

            messages.TranslateNoResult
            messages.TranslateResultText

    Functions:
        This object can be returned by 1 function.

        .. currentmodule:: kymang.raw.functions

        .. autosummary::
            :nosignatures:

            messages.TranslateText
    """

    QUALNAME = "kymang.raw.base.messages.TranslatedText"

    def __init__(self):
        raise TypeError("Base types can only be used for type checking purposes: "
                        "you tried to use a base type instance as argument, "
                        "but you need to instantiate one of its constructors instead. "
                        "More info: https://docs.pyrogram.org/telegram/base/translated-text")
